@@ -1,17 +1,27 @@
 from .structs import Coin
 
 AAVE = Coin("AAVE")
+ACA = Coin("ACA")
 ADA = Coin("ADA")
+AERGO = Coin("AERGO")
 AGLD = Coin("AGLD")
+AKT = Coin("AKT")
 ALGO = Coin("ALGO")
+ALI = Coin("ALI")
 ALICE = Coin("ALICE")
+ALPHA = Coin("ALPHA")
 AMP = Coin("AMP")
+ANC = Coin("ANC")
 ANKR = Coin("ANKR")
 ANY = Coin("ANY")
+APE = Coin("APE")
+API3 = Coin("API3")
 AR = Coin("AR")
 ARPA = Coin("ARPA")
 ATOM = Coin("ATOM")
 AUDIO = Coin("AUDIO")
+AURORA = Coin("AURORA")
+AUTO = Coin("AUTO")
 AVAX = Coin("AVAX")
 AXS = Coin("AXS")
 BADGER = Coin("BADGER")
@@ -20,6 +30,7 @@ BAND = Coin("BAND")
 BAT = Coin("BAT")
 BCH = Coin("BCH")
 BICO = Coin("BICO")
+BIFI = Coin("BIFI")
 BNT = Coin("BNT")
 BOBA = Coin("BOBA")
 BOND = Coin("BOND")
@@ -36,6 +47,7 @@ COMP = Coin("COMP")
 COTI = Coin("COTI")
 CQT = Coin("CQT")
 CRO = Coin("CRO")
+CRPT = Coin("CRPT")
 CRV = Coin("CRV")
 CSPR = Coin("CSPR")
 CTSI = Coin("CTSI")
@@ -43,6 +55,8 @@ CVX = Coin("CVX")
 DAI = Coin("DAI")
 DAR = Coin("DAR")
 DERC = Coin("DERC")
+DGB = Coin("DGB")
+DIA = Coin("DIA")
 DINO = Coin("DINO")
 DOGE = Coin("DOGE")
 DOT = Coin("DOT")
@@ -54,23 +68,30 @@ ENJ = Coin("ENJ")
 ENS = Coin("ENS")
 EOS = Coin("EOS")
 EPS = Coin("EPS")
+ERN = Coin("ERN")
 ETC = Coin("ETC")
 ETH = Coin("ETH")
 FARM = Coin("FARM")
 FET = Coin("FET")
 FIL = Coin("FIL")
+FITFI = Coin("FITFI")
 FLOW = Coin("FLOW")
+FLUX = Coin("FLUX")
 FORTH = Coin("FORTH")
 FTM = Coin("FTM")
 FXS = Coin("FXS")
 GALA = Coin("GALA")
 GHST = Coin("GHST")
 GLM = Coin("GLM")
+GLMR = Coin("GLMR")
+GMT = Coin("GMT")
 GODS = Coin("GODS")
 GRT = Coin("GRT")
 GTC = Coin("GTC")
 GUSD = Coin("GUSD")
 HBAR = Coin("HBAR")
+HERO = Coin("HERO")
+HIGH = Coin("HIGH")
 HNT = Coin("HNT")
 HOD = Coin("HOD")
 HOT = Coin("HOT")
@@ -83,24 +104,35 @@ INJ = Coin("INJ")
 IOTX = Coin("IOTX")
 IQ = Coin("IQ")
 JASMY = Coin("JASMY")
+JOE = Coin("JOE")
 KAVA = Coin("KAVA")
 KEEP = Coin("KEEP")
 KLAY = Coin("KLAY")
 KNC = Coin("KNC")
+KP3R = Coin("KP3R")
+KRL = Coin("KRL")
 KSM = Coin("KSM")
+LDO = Coin("LDO")
 LINK = Coin("LINK")
 LPT = Coin("LPT")
 LRC = Coin("LRC")
+LSK = Coin("LSK")
 LTC = Coin("LTC")
 LUNA = Coin("LUNA")
 MANA = Coin("MANA")
 MASK = Coin("MASK")
 MATIC = Coin("MATIC")
+MBL = Coin("MBL")
+MC = Coin("MC")
 MCO = Coin("MCO")
+MDT = Coin("MDT")
 MIR = Coin("MIR")
 MKR = Coin("MKR")
 MLN = Coin("MLN")
+MMF = Coin("MMF")
 MOVR = Coin("MOVR")
+MULTI = Coin("MULTI")
+MXC = Coin("MXC")
 NANO = Coin("NANO")
 NEAR = Coin("NEAR")
 NEO = Coin("NEO")
@@ -122,13 +154,18 @@ PLA = Coin("PLA")
 POLS = Coin("POLS")
 POLY = Coin("POLY")
 POWR = Coin("POWR")
+PRQ = Coin("PRQ")
+PYR = Coin("PYR")
 QI = Coin("QI")
 QNT = Coin("QNT")
+QRDO = Coin("QRDO")
 QTUM = Coin("QTUM")
 QUICK = Coin("QUICK")
 RAD = Coin("RAD")
 RADAR = Coin("RADAR")
 RARI = Coin("RARI")
+RAY = Coin("RAY")
+REEF = Coin("REEF")
 REN = Coin("REN")
 REQ = Coin("REQ")
 RGT = Coin("RGT")
@@ -148,12 +185,14 @@ SLP = Coin("SLP")
 SNX = Coin("SNX")
 SOL = Coin("SOL")
 SPELL = Coin("SPELL")
+SPS = Coin("SPS")
 SRM = Coin("SRM")
 STORJ = Coin("STORJ")
 STRAX = Coin("STRAX")
 STX = Coin("STX")
 SUPER = Coin("SUPER")
 SUSHI = Coin("SUSHI")
+T = Coin("T")
 TFUEL = Coin("TFUEL")
 THETA = Coin("THETA")
 TONIC = Coin("TONIC")
@@ -167,24 +206,28 @@ USDC = Coin("USDC")
 USDP = Coin("USDP")
 USDT = Coin("USDT")
 VET = Coin("VET")
+VOXEL = Coin("VOXEL")
+VRA = Coin("VRA")
 VTHO = Coin("VTHO")
 VVS = Coin("VVS")
 WAVE = Coin("WAVE")
 WAVES = Coin("WAVES")
 WAXP = Coin("WAXP")
 WBTC = Coin("WBTC")
+WEMIX = Coin("WEMIX")
+WOO = Coin("WOO")
 XLM = Coin("XLM")
 XRP = Coin("XRP")
 XTZ = Coin("XTZ")
 XYO = Coin("XYO")
 YFI = Coin("YFI")
 YGG = Coin("YGG")
+ZBC = Coin("ZBC")
 ZIL = Coin("ZIL")
 ZRX = Coin("ZRX")
 
 
 def all():
     return [
-        value for name, value in globals().items()
-        if isinstance(value, Coin)
+        value for name, value in globals().items() if isinstance(value, Coin)
     ]
